@@ -1,7 +1,8 @@
 m <- SDMtune:::bm_maxent
+x <- SDMmodel2MaxEnt(m)
 
 test_that("The function creates the correct output", {
-  expect_s4_class(x <- SDMmodel2MaxEnt(m), "MaxEnt")
+  expect_s4_class(x, "MaxEnt")
   expect_equal(x@presence, .get_presence(m@data))
   expect_equal(x@absence, .get_absence(m@data))
   expect_equal(x@lambdas, m@model@lambdas)
